@@ -84,7 +84,7 @@ class Table(object):
     Example:
     ::
 
-        >>> from pyflink.table import TableEnvironment
+        >>> from pyflink.table import EnvironmentSettings, TableEnvironment
         >>> from pyflink.table.expressions import *
         >>> env_settings = EnvironmentSettings.in_streaming_mode()
         >>> t_env = TableEnvironment.create(env_settings)
@@ -122,11 +122,9 @@ class Table(object):
         Example:
         ::
 
-            >>> from pyflink.table import expressions as expr
-            >>> tab.select(tab.key, expr.concat(tab.value, 'hello'))
-            >>> tab.select(expr.col('key'), expr.concat(expr.col('value'), 'hello'))
-
-            >>> tab.select("key, value + 'hello'")
+            >>> from pyflink.table.expressions import col, concat
+            >>> tab.select(tab.key, concat(tab.value, 'hello'))
+            >>> tab.select(col('key'), concat(col('value'), 'hello'))
 
         :return: The result table.
         """
@@ -146,7 +144,6 @@ class Table(object):
         ::
 
             >>> tab.alias("a", "b", "c")
-            >>> tab.alias("a, b, c")
 
         :param field: Field alias.
         :param fields: Additional field aliases.
@@ -164,8 +161,7 @@ class Table(object):
         Example:
         ::
 
-            >>> tab.filter(tab.name == 'Fred')
-            >>> tab.filter("name = 'Fred'")
+            >>> tab.filter(col('name') == 'Fred')
 
         :param predicate: Predicate expression string.
         :return: The result table.
@@ -180,8 +176,7 @@ class Table(object):
         Example:
         ::
 
-            >>> tab.where(tab.name == 'Fred')
-            >>> tab.where("name = 'Fred'")
+            >>> tab.where(col('name') == 'Fred')
 
         :param predicate: Predicate expression string.
         :return: The result table.
@@ -196,8 +191,7 @@ class Table(object):
         Example:
         ::
 
-            >>> tab.group_by(tab.key).select(tab.key, tab.value.avg)
-            >>> tab.group_by("key").select("key, value.avg")
+            >>> tab.group_by(col('key')).select(col('key'), col('value').avg)
 
         :param fields: Group keys.
         :return: The grouped table.
@@ -216,7 +210,7 @@ class Table(object):
         Example:
         ::
 
-            >>> tab.select(tab.key, tab.value).distinct()
+            >>> tab.select(col('key'), col('value')).distinct()
 
         :return: The result table.
         """
@@ -236,9 +230,8 @@ class Table(object):
         Example:
         ::
 
-            >>> left.join(right).where((left.a == right.b) && (left.c > 3))
-            >>> left.join(right).where("a = b && c > 3")
-            >>> left.join(right, left.a == right.b)
+            >>> left.join(right).where((col('a') == col('b')) && (col('c') > 3))
+            >>> left.join(right, col('a') == col('b'))
 
         :param right: Right table.
         :param join_predicate: Optional, the join predicate expression string.
@@ -267,8 +260,7 @@ class Table(object):
         ::
 
             >>> left.left_outer_join(right)
-            >>> left.left_outer_join(right, left.a == right.b)
-            >>> left.left_outer_join(right, "a = b")
+            >>> left.left_outer_join(right, col('a') == col('b'))
 
         :param right: Right table.
         :param join_predicate: Optional, the join predicate expression string.
@@ -296,8 +288,7 @@ class Table(object):
         Example:
         ::
 
-            >>> left.right_outer_join(right, left.a == right.b)
-            >>> left.right_outer_join(right, "a = b")
+            >>> left.right_outer_join(right, col('a') == col('b'))
 
         :param right: Right table.
         :param join_predicate: The join predicate expression string.
@@ -322,8 +313,7 @@ class Table(object):
         Example:
         ::
 
-            >>> left.full_outer_join(right, left.a == right.b)
-            >>> left.full_outer_join(right, "a = b")
+            >>> left.full_outer_join(right, col('a') == col('b'))
 
         :param right: Right table.
         :param join_predicate: The join predicate expression string.
@@ -343,12 +333,10 @@ class Table(object):
         Example:
         ::
 
+            >>> from pyflink.table.expressions import *
             >>> t_env.create_java_temporary_system_function("split",
-           ...     "java.table.function.class.name")
-            >>> tab.join_lateral("split(text, ' ') as (b)", "a = b")
-
-            >>> from pyflink.table import expressions as expr
-            >>> tab.join_lateral(expr.call('split', ' ').alias('b'), expr.col('a') == expr.col('b'))
+            ...     "java.table.function.class.name")
+            >>> tab.join_lateral(call('split', ' ').alias('b'), col('a') == col('b'))
             >>> # take all the columns as inputs
             >>> @udtf(result_types=[DataTypes.INT(), DataTypes.STRING()])
             ... def split_row(row: Row):
@@ -394,9 +382,9 @@ class Table(object):
 
             >>> t_env.create_java_temporary_system_function("split",
             ...     "java.table.function.class.name")
-            >>> tab.left_outer_join_lateral("split(text, ' ') as (b)")
-            >>> from pyflink.table import expressions as expr
-            >>> tab.left_outer_join_lateral(expr.call('split', ' ').alias('b'))
+            >>> from pyflink.table.expressions import *
+            >>> tab.left_outer_join_lateral(call('split', ' ').alias('b'))
+
             >>> # take all the columns as inputs
             >>> @udtf(result_types=[DataTypes.INT(), DataTypes.STRING()])
             ... def split_row(row: Row):
@@ -560,8 +548,7 @@ class Table(object):
         Example:
         ::
 
-            >>> tab.order_by(tab.name.desc)
-            >>> tab.order_by("name.desc")
+            >>> tab.order_by(col('name').desc)
 
         For unbounded tables, this operation requires a sorting on a time attribute or a subsequent
         fetch operation.
@@ -588,10 +575,9 @@ class Table(object):
         ::
 
             # skips the first 3 rows and returns all following rows.
-            >>> tab.order_by(tab.name.desc).offset(3)
-            >>> tab.order_by("name.desc").offset(3)
+            >>> tab.order_by(col('name').desc).offset(3)
             # skips the first 10 rows and returns the next 5 rows.
-            >>> tab.order_by(tab.name.desc).offset(10).fetch(5)
+            >>> tab.order_by(col('name').desc).offset(10).fetch(5)
 
         For unbounded tables, this operation requires a subsequent fetch operation.
 
@@ -613,13 +599,12 @@ class Table(object):
         Returns the first 3 records.
         ::
 
-            >>> tab.order_by(tab.name.desc).fetch(3)
-            >>> tab.order_by("name.desc").fetch(3)
+            >>> tab.order_by(col('name').desc).fetch(3)
 
         Skips the first 10 rows and returns the next 5 rows.
         ::
 
-            >>> tab.order_by(tab.name.desc).offset(10).fetch(5)
+            >>> tab.order_by(col('name').desc).offset(10).fetch(5)
 
         :param fetch: The number of records to return. Fetch must be >= 0.
         :return: The result table.
@@ -675,10 +660,10 @@ class Table(object):
         Example:
         ::
 
-            >>> from pyflink.table import expressions as expr
-            >>> tab.window(Tumble.over(expr.lit(10).minutes).on(tab.rowtime).alias('w')) \\
+            >>> from pyflink.table.expressions import col, lit
+            >>> tab.window(Tumble.over(lit(10).minutes).on(col('rowtime')).alias('w')) \\
             ...     .group_by(col('w')) \\
-            ...     .select(tab.a.sum.alias('a'),
+            ...     .select(col('a').sum.alias('a'),
             ...             col('w').start.alias('b'),
             ...             col('w').end.alias('c'),
             ...             col('w').rowtime.alias('d'))
@@ -700,10 +685,10 @@ class Table(object):
         Example:
         ::
 
-            >>> from pyflink.table import expressions as expr
-            >>> tab.over_window(Over.partition_by(tab.c).order_by(tab.rowtime) \\
+            >>> from pyflink.table.expressions import col, lit
+            >>> tab.over_window(Over.partition_by(col('c')).order_by(col('rowtime')) \\
             ...     .preceding(lit(10).seconds).alias("ow")) \\
-            ...     .select(tab.c, tab.b.count.over(col('ow'), tab.e.sum.over(col('ow'))))
+            ...     .select(col('c'), col('b').count.over(col('ow'), col('e').sum.over(col('ow'))))
 
         .. note::
 
@@ -732,9 +717,8 @@ class Table(object):
         Example:
         ::
 
-            >>> from pyflink.table import expressions as expr
-            >>> tab.add_columns((tab.a + 1).alias('a1'), expr.concat(tab.b, 'sunny').alias('b1'))
-            >>> tab.add_columns("a + 1 as a1, concat(b, 'sunny') as b1")
+            >>> from pyflink.table.expressions import col, concat
+            >>> tab.add_columns((col('a') + 1).alias('a1'), concat(col('b'), 'sunny').alias('b1'))
 
         :param fields: Column list string.
         :return: The result table.
@@ -756,10 +740,9 @@ class Table(object):
         Example:
         ::
 
-            >>> from pyflink.table import expressions as expr
-            >>> tab.add_or_replace_columns((tab.a + 1).alias('a1'),
-            ...                            expr.concat(tab.b, 'sunny').alias('b1'))
-            >>> tab.add_or_replace_columns("a + 1 as a1, concat(b, 'sunny') as b1")
+            >>> from pyflink.table.expressions import col, concat
+            >>> tab.add_or_replace_columns((col('a') + 1).alias('a1'),
+            ...                            concat(col('b'), 'sunny').alias('b1'))
 
         :param fields: Column list string.
         :return: The result table.
@@ -780,8 +763,7 @@ class Table(object):
         Example:
         ::
 
-            >>> tab.rename_columns(tab.a.alias('a1'), tab.b.alias('b1'))
-            >>> tab.rename_columns("a as a1, b as b1")
+            >>> tab.rename_columns(col('a').alias('a1'), col('b').alias('b1'))
 
         :param fields: Column list string.
         :return: The result table.
@@ -801,8 +783,7 @@ class Table(object):
         Example:
         ::
 
-            >>> tab.drop_columns(tab.a, tab.b)
-            >>> tab.drop_columns("a, b")
+            >>> tab.drop_columns(col('a'), col('b'))
 
         :param fields: Column list string.
         :return: The result table.
@@ -824,7 +805,7 @@ class Table(object):
 
             >>> add = udf(lambda x: Row(x + 1, x * x), result_type=DataTypes.Row(
             ... [DataTypes.FIELD("a", DataTypes.INT()), DataTypes.FIELD("b", DataTypes.INT())]))
-            >>> tab.map(add(tab.a)).alias("a, b")
+            >>> tab.map(add(col('a'))).alias("a", "b")
             >>> # take all the columns as inputs
             >>> identity = udf(lambda row: row, result_type=DataTypes.Row(
             ... [DataTypes.FIELD("a", DataTypes.INT()), DataTypes.FIELD("b", DataTypes.INT())]))
@@ -854,7 +835,7 @@ class Table(object):
             ... def split(x, string):
             ...     for s in string.split(","):
             ...         yield x, s
-            >>> tab.flat_map(split(tab.a, table.b))
+            >>> tab.flat_map(split(col('a'), col('b')))
             >>> # take all the columns as inputs
             >>> @udtf(result_types=[DataTypes.INT(), DataTypes.STRING()])
             ... def split_row(row: Row):
@@ -889,7 +870,7 @@ class Table(object):
             ...                   [DataTypes.FIELD("a", DataTypes.FLOAT()),
             ...                    DataTypes.FIELD("b", DataTypes.INT())]),
             ...               func_type="pandas")
-            >>> tab.aggregate(agg(tab.a).alias("a", "b")).select("a, b")
+            >>> tab.aggregate(agg(col('a')).alias("a", "b")).select(col('a'), col('b'))
             >>> # take all the columns as inputs
             >>> # pd is a Pandas.DataFrame
             >>> agg_row = udaf(lambda pd: (pd.a.mean(), pd.a.max()),
@@ -897,7 +878,7 @@ class Table(object):
             ...                   [DataTypes.FIELD("a", DataTypes.FLOAT()),
             ...                    DataTypes.FIELD("b", DataTypes.INT())]),
             ...               func_type="pandas")
-            >>> tab.aggregate(agg.alias("a, b")).select("a, b")
+            >>> tab.aggregate(agg.alias("a", "b")).select(col("a"), col("b"))
 
         :param func: user-defined aggregate function.
         :return: The result table.
@@ -928,7 +909,7 @@ class Table(object):
         ::
 
             >>> table_agg = udtaf(MyTableAggregateFunction())
-            >>> tab.flat_aggregate(table_agg(tab.a).alias("a", "b")).select("a, b")
+            >>> tab.flat_aggregate(table_agg(col('a')).alias("a", "b")).select(col('a'), col('b'))
             >>> # take all the columns as inputs
             >>> class Top2(TableAggregateFunction):
             ...     def emit_value(self, accumulator):
@@ -954,7 +935,7 @@ class Table(object):
             ...         return DataTypes.ROW(
             ...             [DataTypes.FIELD("a", DataTypes.BIGINT())])
             >>> top2 = udtaf(Top2())
-            >>> tab.flat_aggregate(top2.alias("a", "b")).select("a, b")
+            >>> tab.flat_aggregate(top2.alias("a", "b")).select(col("a"), col("b"))
 
         :param func: user-defined table aggregate function.
         :return: The result table.
@@ -985,7 +966,7 @@ class Table(object):
 
             >>> pdf = pd.DataFrame(np.random.rand(1000, 2))
             >>> table = table_env.from_pandas(pdf, ["a", "b"])
-            >>> table.filter(table.a > 0.5).to_pandas()
+            >>> table.filter(col('a') > 0.5).to_pandas()
 
         :return: the result pandas DataFrame.
 
@@ -1156,9 +1137,7 @@ class GroupedTable(object):
         Example:
         ::
 
-            >>> tab.group_by(tab.key).select(tab.key, tab.value.avg.alias('average'))
-            >>> tab.group_by("key").select("key, value.avg as average")
-
+            >>> tab.group_by(col('key')).select(col('key'), col('value').avg.alias('average'))
 
         :param fields: Expression string that contains group keys and aggregate function calls.
         :return: The result table.
@@ -1184,7 +1163,8 @@ class GroupedTable(object):
             ...                   [DataTypes.FIELD("a", DataTypes.FLOAT()),
             ...                    DataTypes.FIELD("b", DataTypes.INT())]),
             ...               func_type="pandas")
-            >>> tab.group_by(tab.a).aggregate(agg(tab.b).alias("c", "d")).select("a, c, d")
+            >>> tab.group_by(col('a')).aggregate(agg(col('b')).alias("c", "d")).select(
+            ...     col('a'), col('c'), col('d'))
             >>> # take all the columns as inputs
             >>> # pd is a Pandas.DataFrame
             >>> agg_row = udaf(lambda pd: (pd.a.mean(), pd.b.max()),
@@ -1192,7 +1172,7 @@ class GroupedTable(object):
             ...                   [DataTypes.FIELD("a", DataTypes.FLOAT()),
             ...                    DataTypes.FIELD("b", DataTypes.INT())]),
             ...               func_type="pandas")
-            >>> tab.group_by(tab.a).aggregate(agg.alias("a, b")).select("a, b")
+            >>> tab.group_by(col('a')).aggregate(agg.alias("a", "b")).select(col('a'), col('b'))
 
         :param func: user-defined aggregate function.
         :return: The result table.
@@ -1223,7 +1203,8 @@ class GroupedTable(object):
         ::
 
             >>> table_agg = udtaf(MyTableAggregateFunction())
-            >>> tab.group_by(tab.c).flat_aggregate(table_agg(tab.a).alias("a")).select("c, a")
+            >>> tab.group_by(col('c')).flat_aggregate(table_agg(col('a')).alias("a")).select(
+            ...     col('c'), col('a'))
             >>> # take all the columns as inputs
             >>> class Top2(TableAggregateFunction):
             ...     def emit_value(self, accumulator):
@@ -1249,7 +1230,9 @@ class GroupedTable(object):
             ...         return DataTypes.ROW(
             ...             [DataTypes.FIELD("a", DataTypes.BIGINT())])
             >>> top2 = udtaf(Top2())
-            >>> tab.group_by(tab.c).flat_aggregate(top2.alias("a", "b")).select("a, b")
+            >>> tab.group_by(col('c')) \\
+            ...    .flat_aggregate(top2.alias("a", "b")) \\
+            ...    .select(col('a'), col('b'))
 
         :param func: user-defined table aggregate function.
         :return: The result table.
@@ -1294,10 +1277,10 @@ class GroupWindowedTable(object):
         Example:
         ::
 
-            >>> from pyflink.table import expressions as expr
-            >>> tab.window(Tumble.over(expr.lit(10).minutes).on(tab.rowtime).alias('w')) \\
+            >>> from pyflink.table.expressions import col, lit
+            >>> tab.window(Tumble.over(lit(10).minutes).on(col('rowtime')).alias('w')) \\
             ...     .group_by(col('w')) \\
-            ...     .select(tab.a.sum.alias('a'),
+            ...     .select(col('a').sum.alias('a'),
             ...             col('w').start.alias('b'),
             ...             col('w').end.alias('c'),
             ...             col('w').rowtime.alias('d'))
@@ -1335,7 +1318,6 @@ class WindowGroupedTable(object):
             >>> window_grouped_table.select(col('key'),
             ...                             col('window').start,
             ...                             col('value').avg.alias('valavg'))
-            >>> window_grouped_table.select("key, window.start, value.avg as valavg")
 
         :param fields: Expression string.
         :return: The result table.
@@ -1361,10 +1343,10 @@ class WindowGroupedTable(object):
             ...                   [DataTypes.FIELD("a", DataTypes.FLOAT()),
             ...                    DataTypes.FIELD("b", DataTypes.INT())]),
             ...               func_type="pandas")
-            >>> window_grouped_table.group_by("w") \
-            ...     .aggregate(agg(window_grouped_table.b) \
-            ...     .alias("c", "d")) \
-            ...     .select("c, d")
+            >>> window_grouped_table.group_by(col("w")) \\
+            ...     .aggregate(agg(col('b'))) \\
+            ...     .alias("c", "d") \\
+            ...     .select(col('c'), col('d'))
             >>> # take all the columns as inputs
             >>> # pd is a Pandas.DataFrame
             >>> agg_row = udaf(lambda pd: (pd.a.mean(), pd.b.max()),
@@ -1372,7 +1354,7 @@ class WindowGroupedTable(object):
             ...                   [DataTypes.FIELD("a", DataTypes.FLOAT()),
             ...                    DataTypes.FIELD("b", DataTypes.INT())]),
             ...               func_type="pandas")
-            >>> window_grouped_table.group_by("w, a").aggregate(agg_row)
+            >>> window_grouped_table.group_by(col("w"), col("a")).aggregate(agg_row)
 
         :param func: user-defined aggregate function.
         :return: The result table.
@@ -1427,7 +1409,6 @@ class OverWindowedTable(object):
             >>> over_windowed_table.select(col('c'),
             ...                            col('b').count.over(col('ow')),
             ...                            col('e').sum.over(col('ow')))
-            >>> over_windowed_table.select("c, b.count over ow, e.sum over ow")
 
         :param fields: Expression string.
         :return: The result table.
@@ -1462,7 +1443,7 @@ class AggregatedTable(object):
             ...                   [DataTypes.FIELD("a", DataTypes.FLOAT()),
             ...                    DataTypes.FIELD("b", DataTypes.INT())]),
             ...               func_type="pandas")
-            >>> tab.aggregate(agg(tab.a).alias("a", "b")).select("a, b")
+            >>> tab.aggregate(agg(col('a')).alias("a", "b")).select(col('a'), col('b'))
             >>> # take all the columns as inputs
             >>> # pd is a Pandas.DataFrame
             >>> agg_row = udaf(lambda pd: (pd.a.mean(), pd.b.max()),
@@ -1470,7 +1451,7 @@ class AggregatedTable(object):
             ...                   [DataTypes.FIELD("a", DataTypes.FLOAT()),
             ...                    DataTypes.FIELD("b", DataTypes.INT())]),
             ...               func_type="pandas")
-            >>> tab.group_by(tab.a).aggregate(agg.alias("a, b")).select("a, b")
+            >>> tab.group_by(col('a')).aggregate(agg.alias("a", "b")).select(col('a'), col('b'))
 
         :param fields: Expression string.
         :return: The result table.
@@ -1502,7 +1483,7 @@ class FlatAggregateTable(object):
         ::
 
             >>> table_agg = udtaf(MyTableAggregateFunction())
-            >>> tab.flat_aggregate(table_agg(tab.a).alias("a", "b")).select("a, b")
+            >>> tab.flat_aggregate(table_agg(col('a')).alias("a", "b")).select(col('a'), col('b'))
             >>> # take all the columns as inputs
             >>> class Top2(TableAggregateFunction):
             ...     def emit_value(self, accumulator):
@@ -1528,7 +1509,9 @@ class FlatAggregateTable(object):
             ...         return DataTypes.ROW(
             ...             [DataTypes.FIELD("a", DataTypes.BIGINT())])
             >>> top2 = udtaf(Top2())
-            >>> tab.group_by(tab.c).flat_aggregate(top2.alias("a", "b")).select("a, b")
+            >>> tab.group_by(col('c')) \\
+            ...    .flat_aggregate(top2.alias("a", "b")) \\
+            ...    .select(col('a'), col('b'))
 
         :param fields: Expression string.
         :return: The result table.
